@@ -49,7 +49,7 @@ class BankAccountTest extends TestCase
     {
         try {
             $this->ba->withdrawMoney(1);
-        } catch (BankAccountException $e) {
+        } catch (BankAccountException) {
             $this->assertEquals(0, $this->ba->getBalance());
 
             return;
@@ -68,7 +68,7 @@ class BankAccountTest extends TestCase
     {
         try {
             $this->ba->depositMoney(-1);
-        } catch (BankAccountException $e) {
+        } catch (BankAccountException) {
             $this->assertEquals(0, $this->ba->getBalance());
 
             return;
