@@ -28,7 +28,7 @@ final class CountConstraint extends Constraint
         return $instance;
     }
 
-    public function matches($other): bool
+    public function matches(mixed $other): bool
     {
         return true;
     }
@@ -37,7 +37,7 @@ final class CountConstraint extends Constraint
     {
         return sprintf(
             'is accepted by %s',
-            self::class,
+            self::class
         );
     }
 
