@@ -27,7 +27,7 @@ final class NamedConstraint extends Constraint
         return $instance;
     }
 
-    public function matches($other): bool
+    public function matches(mixed $other): bool
     {
         return true;
     }
