@@ -7,10 +7,21 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
 use PHPUnit\Framework\TestCase;
 
 class Issue1337Test extends TestCase
 {
+    public static function dataProvider()
+    {
+        return [
+            'c:\\' => [true],
+            // The following is commented out because it no longer works in PHP >= 8.1
+            //0.9    => [true],
+        ];
+    }
+
     /**
      * @dataProvider dataProvider
      */
@@ -18,13 +29,4 @@ class Issue1337Test extends TestCase
     {
         $this->assertTrue($a);
     }
-
-    public function dataProvider()
-    {
-        return [
-            'c:\\' => [true],
-            // The following is commented out because it no longer works in PHP >= 8.1
-            // 0.9    => [true],
-        ];
-    }
 }
