@@ -7,6 +7,8 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
 use PHPUnit\Framework\TestCase;
 
 class Issue503Test extends TestCase
@@ -15,7 +17,7 @@ class Issue503Test extends TestCase
     {
         $this->assertSame(
             "foo\n",
-            "foo\r\n",
+            "foo\r\n"
         );
     }
 }
