@@ -13,6 +13,19 @@ use PHPUnit\Framework\TestCase;
 
 final class DataProviderWithNumericDataSetNameTest extends TestCase
 {
+    public static function provider(): array
+    {
+        return [
+            0 => [
+                'string',
+                0,
+                0.0,
+                ['key' => 'value'],
+                true,
+            ],
+        ];
+    }
+
     /**
      * @dataProvider provider
      */
@@ -29,17 +42,4 @@ final class DataProviderWithNumericDataSetNameTest extends TestCase
         /* @noinspection PhpUnitAssertTrueWithIncompatibleTypeArgumentInspection */
         $this->assertTrue(false);
     }
-
-    public function provider(): array
-    {
-        return [
-            0 => [
-                'string',
-                0,
-                0.0,
-                ['key' => 'value'],
-                true,
-            ],
-        ];
-    }
 }
