@@ -11,22 +11,20 @@
 namespace PHPUnit\Framework\MockObject;
 
 use function sprintf;
-use PHPUnit\Framework\Constraint\IsAnything;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Constraint\IsEqual;
 use PHPUnit\Framework\MockObject\Builder\InvocationMocker;
 use PHPUnit\Framework\MockObject\Stub\ReturnSelf;
 use PHPUnit\Framework\MockObject\Stub\ReturnStub;
 use PHPUnit\Framework\TestCase;
-use PHPUnit\TestFixture\ClassWithAllPossibleReturnTypes;
 use PHPUnit\TestFixture\Foo;
+use PHPUnit\TestFixture\MockObject\ClassWithAllPossibleReturnTypes;
 use PHPUnit\TestFixture\MockObject\ClassWithImplicitProtocol;
 use stdClass;
 
-/**
- * @covers \PHPUnit\Framework\MockObject\Builder\InvocationMocker
- *
- * @small
- */
+#[CoversClass(InvocationMocker::class)]
+#[Small]
 final class InvocationMockerTest extends TestCase
 {
     public function testWillReturnWithOneValue(): void
@@ -36,7 +34,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-            ->willReturn(1);
+             ->willReturn(1);
 
         $this->assertEquals(1, $mock->foo());
     }
@@ -48,21 +46,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-            ->willReturn(1, 2, 3);
-
-        $this->assertEquals(1, $mock->foo());
-        $this->assertEquals(2, $mock->foo());
-        $this->assertEquals(3, $mock->foo());
-    }
-
-    public function testWillReturnOnConsecutiveCalls(): void
-    {
-        $mock = $this->getMockBuilder(stdClass::class)
-            ->addMethods(['foo'])
-            ->getMock();
-
-        $mock->method('foo')
-            ->willReturnOnConsecutiveCalls(1, 2, 3);
+             ->willReturn(1, 2, 3);
 
         $this->assertEquals(1, $mock->foo());
         $this->assertEquals(2, $mock->foo());
@@ -76,7 +60,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-            ->willReturnReference($value);
+             ->willReturnReference($value);
 
         $this->assertNull($mock->foo());
         $value = 'foo';
@@ -91,7 +75,7 @@ final class InvocationMockerTest extends TestCase
 
         $invocationMocker = new InvocationMocker(
             $matcherCollection,
-            new Matcher($this->any()),
+            new Matcher($this->any())
         );
 
         $this->expectException(MethodCannotBeConfiguredException::class);
@@ -107,7 +91,7 @@ final class InvocationMockerTest extends TestCase
         $invocationMocker = $mock->method('methodWithBoolReturnTypeDeclaration');
 
         $this->expectException(IncompatibleReturnValueException::class);
-        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type integer, its declared return type is "bool"');
+        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type int, its declared return type is "bool"');
         $invocationMocker->willReturn(1);
     }
 
@@ -119,7 +103,7 @@ final class InvocationMockerTest extends TestCase
         $invocationMocker = $mock->method(new IsEqual('methodWithBoolReturnTypeDeclaration'));
 
         $this->expectException(IncompatibleReturnValueException::class);
-        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type integer, its declared return type is "bool"');
+        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type int, its declared return type is "bool"');
         $invocationMocker->willReturn(1);
     }
 
@@ -131,7 +115,7 @@ final class InvocationMockerTest extends TestCase
         $invocationMocker = $mock->method('methodWithBoolReturnTypeDeclaration');
 
         $this->expectException(IncompatibleReturnValueException::class);
-        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type integer, its declared return type is "bool"');
+        $this->expectExceptionMessage('Method methodWithBoolReturnTypeDeclaration may not return value of type int, its declared return type is "bool"');
         $invocationMocker->willReturn(true, 1);
     }
 
@@ -146,18 +130,18 @@ final class InvocationMockerTest extends TestCase
         $this->expectExceptionMessage(sprintf(
             'Method methodWithClassReturnTypeDeclaration may not return value of type %s, its declared return type is "%s"',
             Foo::class,
-            stdClass::class,
+            stdClass::class
         ));
         $invocationMocker->willReturn(new Foo);
     }
 
     public function testWillReturnAllowsMatchersForMultipleMethodsWithDifferentReturnTypes(): void
     {
-        /** @var ClassWithAllPossibleReturnTypes|MockObject $mock */
+        /** @var ClassWithAllPossibleReturnTypes|\PHPUnit\Framework\MockObject\MockObject $mock */
         $mock = $this->getMockBuilder(ClassWithAllPossibleReturnTypes::class)
             ->getMock();
 
-        $invocationMocker = $mock->method(new IsAnything);
+        $invocationMocker = $mock->method(new \PHPUnit\Framework\Constraint\IsAnything);
         $invocationMocker->willReturn(true, 1);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
@@ -170,7 +154,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodWithBoolReturnTypeDeclaration')
-            ->willReturn(true);
+             ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
     }
@@ -181,7 +165,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodWithBoolReturnTypeDeclaration')
-            ->willReturn(true);
+             ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodwithboolreturntypedeclaration());
     }
@@ -192,7 +176,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodwithboolreturntypedeclaration')
-            ->willReturn(true);
+             ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
     }
@@ -202,12 +186,12 @@ final class InvocationMockerTest extends TestCase
      */
     public function testWillReturnFailsWhenTryingToReturnValueFromVoidMethod(): void
     {
-        /** @var ClassWithAllPossibleReturnTypes|MockObject $out */
+        /** @var ClassWithAllPossibleReturnTypes|\PHPUnit\Framework\MockObject\MockObject $out */
         $out    = $this->createMock(ClassWithAllPossibleReturnTypes::class);
         $method = $out->method('methodWithVoidReturnTypeDeclaration');
 
         $this->expectException(IncompatibleReturnValueException::class);
-        $this->expectExceptionMessage('Method methodWithVoidReturnTypeDeclaration may not return value of type boolean, its declared return type is "void"');
+        $this->expectExceptionMessage('Method methodWithVoidReturnTypeDeclaration may not return value of type bool, its declared return type is "void"');
         $method->willReturn(true);
     }
 
@@ -251,10 +235,10 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-            ->willReturn(new ReturnStub('foo'));
+             ->willReturn(new ReturnStub('foo'));
 
         $mock->method('bar')
-            ->willReturn(new ReturnSelf);
+             ->willReturn(new ReturnSelf);
 
         $this->assertSame('foo', $mock->foo());
         $this->assertSame($mock, $mock->bar());
