@@ -9,9 +9,11 @@
  */
 namespace PHPUnit\Framework\MockObject;
 
+use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\Type;
 
+#[CoversClass(ConfigurableMethod::class)]
 final class ConfigurableMethodTest extends TestCase
 {
     public function testMethodMayReturnValueThatCanBeAssigned(): void
@@ -19,7 +21,7 @@ final class ConfigurableMethodTest extends TestCase
         $type = $this->createMock(Type::class);
 
         $type->method('isAssignable')
-            ->willReturn(true);
+             ->willReturn(true);
 
         $method = new ConfigurableMethod('foo', $type);
 
@@ -31,7 +33,7 @@ final class ConfigurableMethodTest extends TestCase
         $type = $this->createMock(Type::class);
 
         $type->method('isAssignable')
-            ->willReturn(false);
+             ->willReturn(false);
 
         $method = new ConfigurableMethod('foo', $type);
 
