@@ -15,49 +15,55 @@ use function method_exists;
 use function microtime;
 use Countable;
 use Exception;
-use PHPUnit\Framework\InvalidArgumentException;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\RequiresPhp;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
+use PHPUnit\Framework\MockObject\Builder\InvocationMocker;
+use PHPUnit\Framework\MockObject\Rule\InvocationOrder;
+use PHPUnit\Framework\MockObject\Rule\InvokedCount;
+use PHPUnit\Framework\MockObject\Rule\MethodName;
+use PHPUnit\Framework\MockObject\Stub\ReturnStub;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\TestFixture\AbstractTrait;
-use PHPUnit\TestFixture\AnInterface;
-use PHPUnit\TestFixture\AnInterfaceWithReturnType;
-use PHPUnit\TestFixture\AnotherInterface;
-use PHPUnit\TestFixture\ClassWithVariadicArgumentMethod;
 use PHPUnit\TestFixture\ExceptionWithThrowable;
-use PHPUnit\TestFixture\FinalClass;
-use PHPUnit\TestFixture\InterfaceWithSemiReservedMethodName;
 use PHPUnit\TestFixture\MockObject\AbstractMockTestClass;
+use PHPUnit\TestFixture\MockObject\AnInterface;
+use PHPUnit\TestFixture\MockObject\AnInterfaceWithReturnType;
+use PHPUnit\TestFixture\MockObject\AnotherInterface;
+use PHPUnit\TestFixture\MockObject\ClassWithVariadicArgumentMethod;
+use PHPUnit\TestFixture\MockObject\FinalClass;
+use PHPUnit\TestFixture\MockObject\InterfaceWithSemiReservedMethodName;
 use PHPUnit\TestFixture\MockObject\ReadonlyClass;
 use PHPUnit\TestFixture\SingletonClass;
 use RuntimeException;
 use stdClass;
 use Throwable;
 
-/**
- * @covers \PHPUnit\Framework\MockObject\Generator
- *
- * @uses \PHPUnit\Framework\MockObject\Builder\InvocationMocker
- * @uses \PHPUnit\Framework\MockObject\Invocation
- * @uses \PHPUnit\Framework\MockObject\InvocationHandler
- * @uses \PHPUnit\Framework\MockObject\Matcher
- * @uses \PHPUnit\Framework\MockObject\Rule\InvocationOrder
- * @uses \PHPUnit\Framework\MockObject\Rule\InvokedCount
- * @uses \PHPUnit\Framework\MockObject\Rule\MethodName
- * @uses \PHPUnit\Framework\MockObject\Stub\ReturnStub
- *
- * @small
- */
+#[CoversClass(Generator::class)]
+#[UsesClass(InvocationMocker::class)]
+#[UsesClass(Invocation::class)]
+#[UsesClass(InvocationHandler::class)]
+#[UsesClass(Matcher::class)]
+#[UsesClass(InvocationOrder::class)]
+#[UsesClass(InvokedCount::class)]
+#[UsesClass(MethodName::class)]
+#[UsesClass(ReturnStub::class)]
+#[Small]
 final class GeneratorTest extends TestCase
 {
-    /**
-     * @var Generator
-     */
-    private $generator;
+    private ?Generator $generator;
 
     protected function setUp(): void
     {
         $this->generator = new Generator;
     }
 
+    protected function tearDown(): void
+    {
+        $this->generator = null;
+    }
+
     public function testGetMockThrowsExceptionWhenInvalidFunctionNameIsPassedInAsAFunctionToMock(): void
     {
         $this->expectException(InvalidMethodNameException::class);
@@ -65,13 +71,6 @@ final class GeneratorTest extends TestCase
         $this->generator->getMock(stdClass::class, [0]);
     }
 
-    public function testGetMockThrowsExceptionWithInvalidMethods(): void
-    {
-        $this->expectException(InvalidArgumentException::class);
-
-        $this->generator->getMock(stdClass::class, false);
-    }
-
     public function testGetMockThrowsExceptionWithNonExistingClass(): void
     {
         $this->expectException(UnknownTypeException::class);
@@ -143,7 +142,7 @@ final class GeneratorTest extends TestCase
             true,
             true,
             true,
-            ['nonexistentMethod'],
+            ['nonexistentMethod']
         );
 
         $this->assertTrue(method_exists($mock, 'nonexistentMethod'));
@@ -155,7 +154,7 @@ final class GeneratorTest extends TestCase
         $mock = $this->generator->getMockForAbstractClass(AbstractMockTestClass::class);
 
         $mock->method('doSomething')
-            ->willReturn('testing');
+             ->willReturn('testing');
 
         $this->assertEquals('testing', $mock->doSomething());
         $this->assertEquals(1, $mock->returnAnything());
@@ -177,7 +176,7 @@ final class GeneratorTest extends TestCase
             true,
             true,
             true,
-            ['nonexistentMethod'],
+            ['nonexistentMethod']
         );
 
         $this->assertTrue(method_exists($mock, 'nonexistentMethod'));
@@ -292,7 +291,7 @@ final class GeneratorTest extends TestCase
             false,
             true,
             false,
-            true,
+            true
         );
 
         $arguments = [1, 'foo', false];
@@ -327,9 +326,7 @@ final class GeneratorTest extends TestCase
         $this->createMock(FinalClass::class);
     }
 
-    /**
-     * @requires PHP 8.2
-     */
+    #[RequiresPhp('8.2')]
     public function testCannotMockReadonlyClass(): void
     {
         $this->expectException(ClassIsReadonlyException::class);
@@ -344,7 +341,7 @@ final class GeneratorTest extends TestCase
             [
                 AnInterface::class,
                 AnotherInterface::class,
-            ],
+            ]
         );
 
         $this->assertInstanceOf(AnInterface::class, $stub);
