@@ -9,12 +9,13 @@
  */
 namespace PHPUnit\Framework\MockObject;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\UnknownType;
 
-/**
- * @small
- */
+#[CoversClass(MockMethod::class)]
+#[Small]
 final class MockMethodTest extends TestCase
 {
     public function testGetNameReturnsMethodName(): void
@@ -31,8 +32,8 @@ final class MockMethodTest extends TestCase
             false,
             false,
             null,
-            false,
+            false
         );
-        $this->assertEquals('methodName', $method->getName());
+        $this->assertEquals('methodName', $method->methodName());
     }
 }
