@@ -10,23 +10,19 @@
 namespace PHPUnit\Runner;
 
 use function mt_srand;
-use function sprintf;
-use MultiDependencyTest;
-use NotReorderableTest;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
+use PHPUnit\Framework\TestStatus\TestStatus;
 use PHPUnit\Framework\TestSuite;
-use PHPUnit\TestFixture\EmptyTestCaseTest;
-use PHPUnit\TestFixture\FailureTest;
-use PHPUnit\TestFixture\Success;
+use PHPUnit\Runner\ResultCache\DefaultResultCache;
+use PHPUnit\TestFixture\MultiDependencyTest;
 use PHPUnit\TestFixture\TestWithDifferentSizes;
+use ReflectionClass;
 
-/**
- * @testdox Reordering test execution
- *
- * @group test-reorder
- *
- * @small
- */
+#[CoversClass(TestSuiteSorter::class)]
+#[Small]
 final class TestSuiteSorterTest extends TestCase
 {
     /**
@@ -43,122 +39,7 @@ final class TestSuiteSorterTest extends TestCase
         MultiDependencyTest::class . '::testFive',
     ];
 
-    public function testThrowsExceptionWhenUsingInvalidOrderOption(): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-        $sorter = new TestSuiteSorter;
-
-        $this->expectException(Exception::class);
-        $this->expectExceptionMessage('$order must be one of TestSuiteSorter::ORDER_[DEFAULT|REVERSED|RANDOMIZED|DURATION|SIZE]');
-        $sorter->reorderTestsInSuite($suite, -1, false, TestSuiteSorter::ORDER_DEFAULT);
-    }
-
-    public function testThrowsExceptionWhenUsingInvalidOrderDefectsOption(): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-        $sorter = new TestSuiteSorter;
-
-        $this->expectException(Exception::class);
-        $this->expectExceptionMessage('$orderDefects must be one of TestSuiteSorter::ORDER_DEFAULT, TestSuiteSorter::ORDER_DEFECTS_FIRST');
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_DEFAULT, false, -1);
-    }
-
-    /**
-     * @testdox Empty TestSuite not affected (order=$order, resolve=$resolveDependencies, defects=$orderDefects)
-     *
-     * @dataProvider suiteSorterOptionPermutationsProvider
-     */
-    public function testShouldNotAffectEmptyTestSuite(int $order, bool $resolveDependencies, int $orderDefects): void
-    {
-        $sorter = new TestSuiteSorter;
-        $suite  = new TestSuite;
-
-        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, $orderDefects);
-
-        $this->assertEmpty($suite->tests());
-        $this->assertEmpty($sorter->getOriginalExecutionOrder());
-        $this->assertEmpty($sorter->getExecutionOrder());
-    }
-
-    /**
-     * @dataProvider commonSorterOptionsProvider
-     */
-    public function testBasicExecutionOrderOptions(int $order, bool $resolveDependencies, array $expectedOrder): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-        $sorter = new TestSuiteSorter;
-
-        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, TestSuiteSorter::ORDER_DEFAULT);
-
-        $this->assertSame(self::MULTIDEPENDENCYTEST_EXECUTION_ORDER, $sorter->getOriginalExecutionOrder());
-        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
-    }
-
-    public function testCanSetRandomizationWithASeed(): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-        $sorter = new TestSuiteSorter;
-
-        mt_srand(54321);
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_RANDOMIZED, false, TestSuiteSorter::ORDER_DEFAULT);
-
-        $expectedOrder = [
-            MultiDependencyTest::class . '::testTwo',
-            MultiDependencyTest::class . '::testFour',
-            MultiDependencyTest::class . '::testFive',
-            MultiDependencyTest::class . '::testThree',
-            MultiDependencyTest::class . '::testOne',
-        ];
-
-        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
-    }
-
-    public function testCanSetRandomizationWithASeedAndResolveDependencies(): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-        $sorter = new TestSuiteSorter;
-
-        mt_srand(54321);
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_RANDOMIZED, true, TestSuiteSorter::ORDER_DEFAULT);
-
-        $expectedOrder = [
-            MultiDependencyTest::class . '::testTwo',
-            MultiDependencyTest::class . '::testFive',
-            MultiDependencyTest::class . '::testOne',
-            MultiDependencyTest::class . '::testThree',
-            MultiDependencyTest::class . '::testFour',
-        ];
-
-        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
-    }
-
-    /**
-     * @dataProvider orderDurationWithoutCacheProvider
-     */
-    public function testOrderDurationWithoutCache(bool $resolveDependencies, array $expected): void
-    {
-        $suite = new TestSuite;
-
-        $suite->addTestSuite(MultiDependencyTest::class);
-
-        $sorter = new TestSuiteSorter;
-
-        $sorter->reorderTestsInSuite(
-            $suite,
-            TestSuiteSorter::ORDER_DURATION,
-            $resolveDependencies,
-            TestSuiteSorter::ORDER_DEFAULT,
-        );
-
-        $this->assertSame($expected, $sorter->getExecutionOrder());
-    }
-
-    public function orderDurationWithoutCacheProvider(): array
+    public static function orderDurationWithoutCacheProvider(): array
     {
         return [
             'dependency-ignore' => [
@@ -184,34 +65,7 @@ final class TestSuiteSorterTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider orderDurationWithCacheProvider
-     */
-    public function testOrderDurationWithCache(bool $resolveDependencies, array $testTimes, array $expected): void
-    {
-        $suite = new TestSuite;
-
-        $suite->addTestSuite(MultiDependencyTest::class);
-
-        $cache = new DefaultTestResultCache;
-
-        foreach ($testTimes as $testName => $time) {
-            $cache->setTime(MultiDependencyTest::class . '::' . $testName, $time);
-        }
-
-        $sorter = new TestSuiteSorter($cache);
-
-        $sorter->reorderTestsInSuite(
-            $suite,
-            TestSuiteSorter::ORDER_DURATION,
-            $resolveDependencies,
-            TestSuiteSorter::ORDER_DEFAULT,
-        );
-
-        $this->assertSame($expected, $sorter->getExecutionOrder());
-    }
-
-    public function orderDurationWithCacheProvider(): array
+    public static function orderDurationWithCacheProvider(): array
     {
         return [
             'duration-same-dependency-ignore' => [
@@ -285,27 +139,6 @@ final class TestSuiteSorterTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider defectsSorterOptionsProvider
-     */
-    public function testSuiteSorterDefectsOptions(int $order, bool $resolveDependencies, array $runState, array $expected): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(MultiDependencyTest::class);
-
-        $cache = new DefaultTestResultCache;
-
-        foreach ($runState as $testName => $data) {
-            $cache->setState(MultiDependencyTest::class . '::' . $testName, $data['state']);
-            $cache->setTime(MultiDependencyTest::class . '::' . $testName, $data['time']);
-        }
-
-        $sorter = new TestSuiteSorter($cache);
-        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, TestSuiteSorter::ORDER_DEFECTS_FIRST);
-
-        $this->assertSame($expected, $sorter->getExecutionOrder());
-    }
-
     /**
      * A @dataprovider for basic execution reordering options based on MultiDependencyTest.
      *
@@ -316,7 +149,7 @@ final class TestSuiteSorterTest extends TestCase
      * - 'testFour' @depends on 'MultiDependencyTest::testThree' to test FQN @depends
      * - 'testFive' has no dependencies
      */
-    public function commonSorterOptionsProvider(): array
+    public static function commonSorterOptionsProvider(): array
     {
         return [
             'default' => [
@@ -382,7 +215,7 @@ final class TestSuiteSorterTest extends TestCase
      * - 'testFour' @depends on 'MultiDependencyTest::testThree' to test FQN @depends
      * - 'testFive' has no dependencies
      */
-    public function defectsSorterOptionsProvider(): array
+    public static function defectsSorterOptionsProvider(): array
     {
         return [
             // The most simple situation should work as normal
@@ -390,11 +223,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::IGNORE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::success(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testOne',
@@ -426,11 +259,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::IGNORE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::skipped(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testFive',
@@ -446,11 +279,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::IGNORE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 0],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::skipped(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::skipped(), 'time' => 0],
                 ],
                 [
                     MultiDependencyTest::class . '::testFive',
@@ -466,11 +299,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::IGNORE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::skipped(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::success(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testThree',
@@ -486,11 +319,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::RESOLVE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::skipped(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::success(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testOne',
@@ -506,11 +339,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_REVERSED,
                 self::IGNORE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::skipped(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::success(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testThree',
@@ -527,11 +360,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::RESOLVE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 0],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::skipped(), 'time' => 0],
+                    'testFour'  => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::skipped(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testFive',
@@ -551,9 +384,9 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_REVERSED,
                 self::RESOLVE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_SKIPPED, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::skipped(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testFive',
@@ -571,11 +404,11 @@ final class TestSuiteSorterTest extends TestCase
                 TestSuiteSorter::ORDER_DEFAULT,
                 self::RESOLVE_DEPENDENCIES,
                 [
-                    'testOne'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testTwo'   => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testThree' => ['state' => BaseTestRunner::STATUS_PASSED, 'time' => 1],
-                    'testFour'  => ['state' => BaseTestRunner::STATUS_FAILURE, 'time' => 1],
-                    'testFive'  => ['state' => BaseTestRunner::STATUS_FAILURE, 'time' => 1],
+                    'testOne'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testTwo'   => ['state' => TestStatus::success(), 'time' => 1],
+                    'testThree' => ['state' => TestStatus::success(), 'time' => 1],
+                    'testFour'  => ['state' => TestStatus::failure(), 'time' => 1],
+                    'testFive'  => ['state' => TestStatus::failure(), 'time' => 1],
                 ],
                 [
                     MultiDependencyTest::class . '::testFive',
@@ -588,29 +421,7 @@ final class TestSuiteSorterTest extends TestCase
         ];
     }
 
-    /**
-     * @see https://github.com/lstrojny/phpunit-clever-and-smart/issues/38
-     */
-    public function testCanHandleSuiteWithEmptyTestCase(): void
-    {
-        $suite = new TestSuite;
-        $suite->addTestSuite(EmptyTestCaseTest::class);
-
-        $sorter = new TestSuiteSorter;
-
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_DEFAULT, false, TestSuiteSorter::ORDER_DEFAULT);
-
-        $this->assertSame(EmptyTestCaseTest::class, $suite->tests()[0]->getName());
-        $this->assertSame(
-            sprintf(
-                'No tests found in class "%s".',
-                EmptyTestCaseTest::class,
-            ),
-            $suite->tests()[0]->tests()[0]->getMessage(),
-        );
-    }
-
-    public function suiteSorterOptionPermutationsProvider(): array
+    public static function suiteSorterOptionPermutationsProvider(): array
     {
         $orderValues        = [TestSuiteSorter::ORDER_DEFAULT, TestSuiteSorter::ORDER_REVERSED, TestSuiteSorter::ORDER_RANDOMIZED];
         $resolveValues      = [false, true];
@@ -629,10 +440,161 @@ final class TestSuiteSorterTest extends TestCase
         return $data;
     }
 
+    public function testThrowsExceptionWhenUsingInvalidOrderOption(): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+        $sorter = new TestSuiteSorter;
+
+        $this->expectException(InvalidOrderException::class);
+
+        $sorter->reorderTestsInSuite($suite, -1, false, TestSuiteSorter::ORDER_DEFAULT);
+    }
+
+    public function testThrowsExceptionWhenUsingInvalidOrderDefectsOption(): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+        $sorter = new TestSuiteSorter;
+
+        $this->expectException(InvalidOrderException::class);
+
+        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_DEFAULT, false, -1);
+    }
+
+    #[DataProvider('suiteSorterOptionPermutationsProvider')]
+    public function testShouldNotAffectEmptyTestSuite(int $order, bool $resolveDependencies, int $orderDefects): void
+    {
+        $sorter = new TestSuiteSorter;
+        $suite  = TestSuite::empty();
+
+        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, $orderDefects);
+
+        $this->assertEmpty($suite->tests());
+        $this->assertEmpty($sorter->getOriginalExecutionOrder());
+        $this->assertEmpty($sorter->getExecutionOrder());
+    }
+
+    #[DataProvider('commonSorterOptionsProvider')]
+    public function testBasicExecutionOrderOptions(int $order, bool $resolveDependencies, array $expectedOrder): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+        $sorter = new TestSuiteSorter;
+
+        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, TestSuiteSorter::ORDER_DEFAULT);
+
+        $this->assertSame(self::MULTIDEPENDENCYTEST_EXECUTION_ORDER, $sorter->getOriginalExecutionOrder());
+        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
+    }
+
+    public function testCanSetRandomizationWithASeed(): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+        $sorter = new TestSuiteSorter;
+
+        mt_srand(54321);
+        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_RANDOMIZED, false, TestSuiteSorter::ORDER_DEFAULT);
+
+        $expectedOrder = [
+            MultiDependencyTest::class . '::testTwo',
+            MultiDependencyTest::class . '::testFour',
+            MultiDependencyTest::class . '::testFive',
+            MultiDependencyTest::class . '::testThree',
+            MultiDependencyTest::class . '::testOne',
+        ];
+
+        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
+    }
+
+    public function testCanSetRandomizationWithASeedAndResolveDependencies(): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+        $sorter = new TestSuiteSorter;
+
+        mt_srand(54321);
+        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_RANDOMIZED, true, TestSuiteSorter::ORDER_DEFAULT);
+
+        $expectedOrder = [
+            MultiDependencyTest::class . '::testTwo',
+            MultiDependencyTest::class . '::testFive',
+            MultiDependencyTest::class . '::testOne',
+            MultiDependencyTest::class . '::testThree',
+            MultiDependencyTest::class . '::testFour',
+        ];
+
+        $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
+    }
+
+    #[DataProvider('orderDurationWithoutCacheProvider')]
+    public function testOrderDurationWithoutCache(bool $resolveDependencies, array $expected): void
+    {
+        $suite = TestSuite::empty();
+
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+
+        $sorter = new TestSuiteSorter;
+
+        $sorter->reorderTestsInSuite(
+            $suite,
+            TestSuiteSorter::ORDER_DURATION,
+            $resolveDependencies,
+            TestSuiteSorter::ORDER_DEFAULT
+        );
+
+        $this->assertSame($expected, $sorter->getExecutionOrder());
+    }
+
+    #[DataProvider('orderDurationWithCacheProvider')]
+    public function testOrderDurationWithCache(bool $resolveDependencies, array $testTimes, array $expected): void
+    {
+        $suite = TestSuite::empty();
+
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+
+        $cache = new DefaultResultCache;
+
+        foreach ($testTimes as $testName => $time) {
+            $cache->setTime(MultiDependencyTest::class . '::' . $testName, $time);
+        }
+
+        $sorter = new TestSuiteSorter($cache);
+
+        $sorter->reorderTestsInSuite(
+            $suite,
+            TestSuiteSorter::ORDER_DURATION,
+            $resolveDependencies,
+            TestSuiteSorter::ORDER_DEFAULT
+        );
+
+        $this->assertSame($expected, $sorter->getExecutionOrder());
+    }
+
+    #[DataProvider('defectsSorterOptionsProvider')]
+    public function testSuiteSorterDefectsOptions(int $order, bool $resolveDependencies, array $runState, array $expected): void
+    {
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(MultiDependencyTest::class));
+
+        $cache = new DefaultResultCache;
+
+        foreach ($runState as $testName => $data) {
+            $cache->setStatus(MultiDependencyTest::class . '::' . $testName, $data['state']);
+            $cache->setTime(MultiDependencyTest::class . '::' . $testName, $data['time']);
+        }
+
+        $sorter = new TestSuiteSorter($cache);
+        $sorter->reorderTestsInSuite($suite, $order, $resolveDependencies, TestSuiteSorter::ORDER_DEFECTS_FIRST);
+
+        $this->assertSame($expected, $sorter->getExecutionOrder());
+    }
+
     public function testOrderBySize(): void
     {
-        $suite = new TestSuite;
-        $suite->addTestSuite(TestWithDifferentSizes::class);
+        $suite = TestSuite::empty();
+        $suite->addTestSuite(new ReflectionClass(TestWithDifferentSizes::class));
         $sorter = new TestSuiteSorter;
 
         $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_SIZE, true, TestSuiteSorter::ORDER_DEFAULT);
@@ -650,16 +612,4 @@ final class TestSuiteSorterTest extends TestCase
 
         $this->assertSame($expectedOrder, $sorter->getExecutionOrder());
     }
-
-    public function testSorterQuietlyIgnoresNonReorderable(): void
-    {
-        $suite          = new TestSuite;
-        $testCollection = [new Success, new NotReorderableTest, new FailureTest];
-        $suite->setTests($testCollection);
-
-        $sorter = new TestSuiteSorter;
-        $sorter->reorderTestsInSuite($suite, TestSuiteSorter::ORDER_DURATION, true, TestSuiteSorter::ORDER_DEFECTS_FIRST);
-
-        $this->assertEquals($testCollection, $suite->tests());
-    }
 }
