@@ -9,11 +9,12 @@
  */
 namespace PHPUnit\Util;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @small
- */
+#[CoversClass(GlobalState::class)]
+#[Small]
 final class GlobalStateTest extends TestCase
 {
     public function testIncludedFilesAsStringSkipsVfsProtocols(): void
@@ -30,7 +31,7 @@ final class GlobalStateTest extends TestCase
         $this->assertEquals(
             "require_once '" . $dir . "/GlobalStateTest.php';\n" .
             "require_once 'file://" . $dir . "/XmlTest.php';\n",
-            GlobalState::processIncludedFilesAsString($files),
+            GlobalState::processIncludedFilesAsString($files)
         );
     }
 }
