@@ -9,18 +9,16 @@
  */
 namespace PHPUnit\Util\PHP;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @small
- */
+#[CoversClass(AbstractPhpProcess::class)]
+#[Small]
 final class AbstractPhpProcessTest extends TestCase
 {
-    /**
-     * @var AbstractPhpProcess|MockObject
-     */
-    private $phpProcess;
+    private AbstractPhpProcess|MockObject|null $phpProcess;
 
     protected function setUp(): void
     {
