@@ -9,18 +9,17 @@
  */
 namespace PHPUnit\Util\Xml;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @small
- *
- * @covers \PHPUnit\Util\Xml\Loader
- */
+#[CoversClass(Loader::class)]
+#[Small]
 final class LoaderTest extends TestCase
 {
     public function testCannotLoadXmlFromEmptyString(): void
     {
-        $this->expectException(Exception::class);
+        $this->expectException(XmlException::class);
         $this->expectExceptionMessage('Could not load XML from empty string');
 
         (new Loader)->load('');
